@@ -1,16 +1,3 @@
-"""
-Copyright (c) 2020-2022 Go2Market Insights, LLC d/b/a Analyzr
-All rights reserved.
-https://analyzr.ai
-
-The above copyright notice and this permission notice shall be included in all copies or substantial portions
-of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
-THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-"""
 import os, sys, time, json
 import pandas as pd
 from copy import deepcopy
@@ -47,9 +34,9 @@ class BaseRunner:
         """
         :param df:
         :param batch_size:
-        :param client_id:
+        :param client_id: Short name for account being used. Used for reporting purposes only
         :param request_id:
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :param compressed:
         :param staging:
         :return res:
@@ -81,9 +68,9 @@ class BaseRunner:
         :param batch:
         :param idx:
         :param n:
-        :param client_id:
+        :param client_id: Short name for account being used. Used for reporting purposes only
         :param request_id:
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :param compressed:
         :return success:
         """
@@ -112,9 +99,9 @@ class BaseRunner:
 
     def _buffer_read(self, client_id=None, request_id=None, dataframe_name='df', verbose=False, raw=False, staging=False):
         """
-        :param client_id:
+        :param client_id: Short name for account being used. Used for reporting purposes only
         :param request_id:
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :param raw:
         :param staging:
         :return df:
@@ -132,9 +119,9 @@ class BaseRunner:
 
     def __read(self, client_id=None, request_id=None, dataframe_name='df', verbose=False, staging=False):
         """
-        :param client_id:
+        :param client_id: Short name for account being used. Used for reporting purposes only
         :param request_id:
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :param staging:
         :return res:
         """
@@ -149,8 +136,8 @@ class BaseRunner:
 
     def queue_purge(self, client_id=None, verbose=False):
         """
-        :param client_id:
-        :param verbose:
+        :param client_id: Short name for account being used. Used for reporting purposes only
+        :param verbose: Set to true for verbose output
         :return res:
         """
         if verbose: print('Purging queue...')
@@ -164,8 +151,8 @@ class BaseRunner:
 
     def buffer_purge(self, client_id=None, verbose=False):
         """
-        :param client_id:
-        :param verbose:
+        :param client_id: Short name for account being used. Used for reporting purposes only
+        :param verbose: Set to true for verbose output
         :return res:
         """
         if verbose: print('Purging buffer...')
@@ -179,8 +166,8 @@ class BaseRunner:
 
     def buffer_usage(self, client_id=None, verbose=False):
         """
-        :param client_id:
-        :param verbose:
+        :param client_id: Short name for account being used. Used for reporting purposes only
+        :param verbose: Set to true for verbose output
         :return res:
         """
         if verbose: print('Checking buffer usage...')
@@ -194,9 +181,9 @@ class BaseRunner:
 
     def _buffer_clear(self, client_id=None, request_id=None, verbose=False):
         """
-        :param client_id:
+        :param client_id: Short name for account being used. Used for reporting purposes only
         :param request_id:
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :param staging:
         :return res:
         """
@@ -220,7 +207,7 @@ class BaseRunner:
         :param numerical_vars:
         :param record_id_var:
         :param encode_field_names:
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :return df2:
         :return xref: cross-reference dictionary for categorical variables
         :return zref: cross-reference dictionary for numerical variables
@@ -248,7 +235,7 @@ class BaseRunner:
         :param numerical_vars:
         :param record_id_var:
         :param encode_field_names:
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :return df2:
         :return xref: cross-reference dictionary for categorical variables
         :return zref: cross-reference dictionary for numerical variables
@@ -308,7 +295,7 @@ class BaseRunner:
         :param numerical_vars:
         :param record_id_var:
         :param encode_field_names:
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :return df2:
         :return xref: cross-reference dictionary for categorical variables
         :return zref: cross-reference dictionary for numerical variables
@@ -373,7 +360,7 @@ class BaseRunner:
         :param zref: cross-reference dictionary for numerical variables
         :param rref: cross-reference dictionary for the record ID variable
         :param fref: cross-reference dictionary for field names
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :return df2:
         """
         if df is None or df.empty: return df
@@ -416,7 +403,7 @@ class BaseRunner:
         :param payload:
         :param timeout:
         :param step:
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :return res:
         """
         counter = 0
@@ -437,8 +424,8 @@ class BaseRunner:
     def _status(self, request_id=None, client_id=None, verbose=False):
         """
         :param request_id:
-        :param client_id:
-        :param verbose:
+        :param client_id: Short name for account being used. Used for reporting purposes only
+        :param verbose: Set to true for verbose output
         :return res:
         """
         res = {}
@@ -462,7 +449,7 @@ class BaseRunner:
         """
         :param model_id:
         :param keys:
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :return:
         """
         if verbose: print('Saving encoding keys locally...')
@@ -476,7 +463,7 @@ class BaseRunner:
     def _keys_load(self, model_id=None, verbose=False):
         """
         :param model_id:
-        :param verbose:
+        :param verbose: Set to true for verbose output
         :return keys:
         """
         if verbose: print('Loading encoding keys...')
